@@ -15,19 +15,17 @@
 #  License along with this library.
 import argparse
 import asyncio
-import os
 
-import sys
 import aiohttp
-
 import octobot_commons.logging as logging
+import sys
 
+import octobot_tentacles_manager
 import octobot_tentacles_manager.api as api
-import octobot_tentacles_manager.api.updater as updater_api
 import octobot_tentacles_manager.api.installer as installer_api
 import octobot_tentacles_manager.api.uninstaller as uninstaller_api
+import octobot_tentacles_manager.api.updater as updater_api
 import octobot_tentacles_manager.constants as constants
-import octobot_tentacles_manager
 
 
 async def _handle_package_manager_command(starting_args,
@@ -46,18 +44,24 @@ async def _handle_package_manager_command(starting_args,
     async with aiohttp.ClientSession() as aiohttp_session:
         include_dev_mode = starting_args.include_dev_mode
         include_tentacles_export = starting_args.include_tentacles_export
+        should_use_package_name_when_exporting = starting_args.export_with_package_name
+        upload_tentacles_export_list = starting_args.upload_tentacles_export \
+            if starting_args.upload_tentacles_export else []
         if starting_args.creator:
             error_count = api.start_tentacle_creator({}, starting_args.creator)
         elif starting_args.repair:
             error_count = await api.repair_installation(bot_path=target_dir)
         elif starting_args.export:
-            error_count = await api.create_tentacles_package(export_tentacles_output,
-                                                             target_dir,
-                                                             exported_tentacles_package=exported_tentacles_package,
-                                                             in_zip=False,
-                                                             with_dev_mode=include_dev_mode,
-                                                             upload_details=starting_args.upload_package_export,
-                                                             cythonize=cythonize)
+            error_count = await api.create_tentacles_package(
+                export_tentacles_output,
+                target_dir,
+                exported_tentacles_package=exported_tentacles_package,
+                in_zip=False,
+                with_dev_mode=include_dev_mode,
+                upload_details=starting_args.upload_package_export,
+                cythonize=cythonize,
+                metadata_file=starting_args.metadata_file,
+                use_package_as_file_name=should_use_package_name_when_exporting)
             if include_tentacles_export:
                 error_count += await api.create_all_tentacles_bundle(
                     output_dir=export_tentacles_output,
@@ -65,18 +69,21 @@ async def _handle_package_manager_command(starting_args,
                     exported_tentacles_package=exported_tentacles_package,
                     in_zip=False,
                     should_remove_artifacts_after_use=True,
-                    upload_url=starting_args.upload_tentacles_export[0]
-                    if len(starting_args.upload_tentacles_export) > 0 else None,
+                    upload_url=upload_tentacles_export_list[0]
+                    if len(upload_tentacles_export_list) > 0 else None,
                     with_dev_mode=include_dev_mode,
                     cythonize=cythonize)
         elif starting_args.pack:
-            error_count = await api.create_tentacles_package(packed_tentacles_output,
-                                                             target_dir,
-                                                             exported_tentacles_package=exported_tentacles_package,
-                                                             in_zip=True,
-                                                             with_dev_mode=include_dev_mode,
-                                                             upload_details=starting_args.upload_package_export,
-                                                             cythonize=cythonize)
+            error_count = await api.create_tentacles_package(
+                packed_tentacles_output,
+                target_dir,
+                exported_tentacles_package=exported_tentacles_package,
+                in_zip=True,
+                with_dev_mode=include_dev_mode,
+                upload_details=starting_args.upload_package_export,
+                cythonize=cythonize,
+                metadata_file=starting_args.metadata_file,
+                use_package_as_file_name=should_use_package_name_when_exporting)
             if include_tentacles_export:
                 error_count += await api.create_all_tentacles_bundle(
                     output_dir=export_tentacles_output,
@@ -85,8 +92,8 @@ async def _handle_package_manager_command(starting_args,
                     in_zip=True,
                     with_dev_mode=include_dev_mode,
                     should_remove_artifacts_after_use=True,
-                    upload_url=starting_args.upload_tentacles_export[0]
-                    if len(starting_args.upload_tentacles_export) > 0 else None,
+                    upload_url=upload_tentacles_export_list[0]
+                    if len(upload_tentacles_export_list) > 0 else None,
                     cythonize=cythonize)
         elif single_tentacle_path:
             error_count = await api.install_single_tentacle(single_tentacle_path,
@@ -218,6 +225,10 @@ def register_tentacles_manager_arguments(tentacles_parser) -> None:
                                                          "package): -e myTentaclesFolder OctoBot-Default-Tentacles "
                                                          "-d ./tentacles", nargs="+")
     tentacles_parser.add_argument("-a", "--all", help="Apply command to all available Tentacles.", action='store_true')
+    tentacles_parser.add_argument("--export-with-package-name",
+                                  help="Export package using its artifact's name as package name. When used with "
+                                       "cythonize, the exported package name wont contain the os and the architecture",
+                                  action='store_true')
     tentacles_parser.add_argument("-d", "--directory", help=f"Path to the root of the OctoBot installation folder "
                                                             f"to operate on. Default is '{constants.DEFAULT_BOT_PATH}'.",
                                   nargs=1)
@@ -232,12 +243,12 @@ def register_tentacles_manager_arguments(tentacles_parser) -> None:
                                                                             "pack commands. Usage: <nexus_path>",
                                   nargs=1)
     tentacles_parser.add_argument("-upe", "--upload-package-export", help="Upload package during export and "
-                                                                          "pack commands. "
-                                                                          "Usage: <nexus_path> [package_alias]",
-                                  nargs='+')
+                                                                          "pack commands. Usage: <nexus_path>",
+                                  nargs=1)
     tentacles_parser.add_argument("-c", "--creator", help="Start OctoBot Tentacles Creator.\n Examples: -c Evaluator "
                                                           "to create a new evaluator tentacles. Use: -c help to get the"
                                                           " Tentacle Creator help.", nargs='+')
+    tentacles_parser.add_argument("-m", "--metadata-file", help="The metadata file to use when exporting the package.")
     tentacles_parser.add_argument("-cy", "--cythonize", help="Option for the --pack command: cythonize and "
                                                              "compile the packed tentacles.", action='store_true')
     tentacles_parser.add_argument("-nu", "--nexus-upload", help="Upload a file or files of folder to nexus at path."
