@@ -20,7 +20,7 @@ import octobot_commons.enums as enums
 CURRENT_DIR_PATH = "."
 
 # Default tests tentacles URL
-DEFAULT_TENTACLES_URL = "https://www.tentacles.octobot.online/repository/tentacles/officials/base/tests/0.0.2-tests.zip"
+DEFAULT_TENTACLES_URL = "https://www.tentacles.octobot.online/repository/tentacles/dev/packages/tests/0.0.2.zip"
 DEFAULT_BOT_INSTALL_DIR = CURRENT_DIR_PATH
 
 # Tentacles files
@@ -49,10 +49,13 @@ METADATA_TENTACLES_GROUP = "tentacles_group"
 ARTIFACT_METADATA_FILE = "metadata.yaml"
 ARTIFACT_METADATA_VERSION = "version"
 ARTIFACT_METADATA_NAME = "name"
+ARTIFACT_METADATA_SHORT_NAME = "short-name"
 ARTIFACT_METADATA_ARTIFACT_TYPE = "type"
 ARTIFACT_METADATA_REPOSITORY = "repository"
 ARTIFACT_METADATA_AUTHOR = "author"
-ARTIFACT_METADATA_ARTIFACTS = "artifacts"
+ARTIFACT_METADATA_DESCRIPTION = "description"
+ARTIFACT_METADATA_TAGS = "tags"
+ARTIFACT_METADATA_TENTACLES = "tentacles"
 DEFAULT_ARTIFACT_METADATA_AUTHOR = "DrakkarSoftware"
 
 # Requirements
@@ -79,9 +82,11 @@ TENTACLES_PACKAGE_PROFILES_PATH = "profiles"
 
 # exporter
 DEFAULT_EXPORT_DIR = "output"
+ANY_PLATFORM_FILE_NAME = "any_platform"
 
 # Artifacts
 UNKNOWN_ARTIFACT_VERSION = "unknown_version"
+ARTIFACT_VERSION_SEPARATOR = "@"
 
 # Tentacles installation folders
 TENTACLES_INSTALL_TEMP_DIR = "temp_tentacles"
